@@ -13,7 +13,7 @@ BEGIN
     require ExtUtils::ModuleMaker;
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION = '0.01';
+    $VERSION = '0.02';
     @ISA     = qw(Exporter ExtUtils::ModuleMaker);
 
     #Give a hoot don't pollute, do not export more than needed by default
@@ -99,6 +99,7 @@ sub block_begin
     my $Id_line               = q{#$Id#} . "\n";
     my $strict_line           = "use strict;\n";
     my $warnings_line         = "use warnings;\n";                                           # not included in standard version
+    my $carp_line             = "use Carp;\n";
     my $encoding_line         = "use utf8;\n";
     my $data_dumper_line      = "use Data::Dumper;\n";
     my $log_line              = "use Log::Any qw(\$log);\n";
@@ -123,6 +124,7 @@ END_OF_BEGIN
     $text .= $Id_line               if $self->{ INCLUDE_ID_LINE };
     $text .= $strict_line;
     $text .= $warnings_line         if $self->{ INCLUDE_WARNINGS };
+    $text .= $carp_line;
     $text .= $encoding_line;
     $text .= $data_dumper_line;
     $text .= $log_line;
